# Table of Contents

- [ai-governance-and-adoption](<./ai-governance-and-adoption.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [AI Governance](<./AI-Governance.md>)
  - [Overview](<./AI-Governance/Overview.md>)
  - [What Is AI Governance?](<./AI-Governance/What-Is-AI-Governance.md>)
  - [Why Is AI Governance Relevant?](<./AI-Governance/Why-Is-AI-Governance-Relevant.md>)
  - [What Are the Benefits of AI Governance?](<./AI-Governance/What-Are-the-Benefits-of-AI-Governance.md>)
  - [Before You Start](<./AI-Governance/Before-You-Start.md>)
  - [Step-by-Step Guide](<./AI-Governance/Step-by-Step-Guide.md>)
  - [Related Resources](<./AI-Governance/Related-Resources.md>)
